'''This is just a joke'''

"""This is a function simplest you have ever seen"""
def print_lol(the_list):
    for each_item in the_list:
        if isinstance(each_item,list):
            print_lol(each_item)
        else:
            print(each_item)



from distutils.core import setup

setup(
        name='jyw',
        version='1.0.0',
        py_modules=['jyw'],
        author='j',
        author_email='jiangyiwei@gmail.com',
        url='',
        description='An apple for eye',
    )
